from dbutils_typehint.fs import FS


class DBUtils:
    fs = FS()
